@@ -67,6 +67,10 @@ class API(object):
 
         link = self.domain + 'SymbolsGet' + '/' + symbol
         response = requests.get(link, headers = {'TOKEN': f'{self.token}'})
+        print('response:')
+        print(response)
+        print('response.json():')
+        print(response.json())
         return response.json()
     
     def initialize_price_stream(self, symbol, timeframe):
@@ -87,7 +91,7 @@ class API(object):
         digit = self.symbol_info(symbol)['Digits']
         result = response.json()
         for key in range(len(result)):
-            result[key]['Open'] =round(result[key]['Open'] * (10**-digit), digit)
+            result[key]['Open'] = round(result[key]['Open'] * (10**-digit), digit)
             result[key]['Close'] = round((result[key]['Close'] * (10**-digit)) + result[key]['Open'], digit)
             result[key]['High'] = round((result[key]['High'] * (10**-digit)) + result[key]['Open'], digit)
             result[key]['Low'] = round((result[key]['Low'] * (10**-digit)) + result[key]['Open'], digit)
